==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtaccumHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "accumulation"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "attritute"
#define KEYC "an attribute list based on which the total is calculated (if omitted,    all lines are assumed to take the same key value)"

/*-f*/
#define FLDT "attritute list"
#define FLDC "an attribute list for which the total is calculated"
#define FLDF NULL

/*-s*/
#define SRTT "a list of atributes to be rearranged"
#define SRTC "this determines the ordering of records to be accumuated for those having the same key value"
#define SRTF "numerical order, decreasing order"

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " For each different value of  the attribute specified -k, this command calculates the total of the  values of each attribute specified by -f."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtaccum -k customerID -s date -f amount:total -i dat.xt -o rsl.xt\n\
xtaccum -s date -f amount:total -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtagg,xtstatistics,xtshare"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre4.tar.gz: musashi-core-1.0.4-pre4/help/en/xtaccumHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "accumulation"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "attritute"
#define KEYC "an attribute list based on which the total is calculated (if omitted, all lines are assumed to take the same key value)"

/*-f*/
#define FLDT "attritute list"
#define FLDC "an attribute list for which the total is calculated"
#define FLDF NULL

/*-s*/
#define SRTT "a list of atributes to be rearranged"
#define SRTC "this determines the ordering of records to be accumuated for those having the same key value"
#define SRTF "numerical order, decreasing order"

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "This command calculates the cumulative values for the field argument based on the sequence of the key attribute(s). A user has to specify the key attribute -k for the basis of calculating the cumulative value for each key record, and the field in option -f where the calculations will be performed. And -s determines the ordering of records to be accumuated for those having the same key value. If -k is not specified, the calculation will be based upon all records in the data. The calculated value will be stored as a new attribute appended to the last column of the data, the name of the new attribute should be specified by '-f attribute name:A'."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtaccum -k customerID -s date -f amount:total -i dat.xt -o rsl.xt\n\
xtaccum -s date -f amount:total -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtagg,xtstatistics,xtshare"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
